..  Copyright (C) Stephen Schaub.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: test-1-
   :start: 1

Introduction: Unit Testing
==========================

Testing plays an important role in the development of software. To this point, most of the testing you have done has probably involved
running your program and fixing errors as you notice them. In this chapter, you will learn about a more methodical approach to testing.
Along the way, you will pick up some design techniques. So, let's get started!

